@@ -33,59 +33,58 @@
 #include <glib.h>
 #include <glib/gstdio.h>
 
-#include <shadowapp.h>
-
 #define NAKO_DATADIR "/usr/games/nako/"
 #define DEFAULT_TILESET "2004.tileset"
 #define DEFAULT_UI "default.ui"
 
-/* Locations of graphic UI elements in the UI file */
-#define GRAB_CLOSE_BUTTON_X 720
-#define GRAB_CLOSE_BUTTON_Y 0
-#define GRAB_CLOSE_BUTTON_X_DOWN 0
-#define GRAB_CLOSE_BUTTON_Y_DOWN 480
-
-#define GRAB_SHUFFLE_BUTTON_X 720
-#define GRAB_SHUFFLE_BUTTON_Y 80
-#define GRAB_SHUFFLE_BUTTON_X_DOWN 80
-#define GRAB_SHUFFLE_BUTTON_Y_DOWN 480
-
-#define GRAB_UP_X 291
-#define GRAB_UP_Y 529
-#define GRAB_UP_X_DOWN 325
-#define GRAB_UP_Y_DOWN 529
-#define GRAB_UP_X_DIMMED 359
-#define GRAB_UP_Y_DIMMED 529
-
-#define GRAB_DOWN_X 291
-#define GRAB_DOWN_Y 542
-#define GRAB_DOWN_X_DOWN 325
-#define GRAB_DOWN_Y_DOWN 542
-#define GRAB_DOWN_X_DIMMED 359
-#define GRAB_DOWN_Y_DIMMED 542
-
-#define GRAB_NUMBERS_X 269
-#define GRAB_NUMBERS_Y 487
-#define GRAB_TILEBACK_X 161
-#define GRAB_TILEBACK_Y 480
-
-#define GRAB_DIF_W 60
-#define GRAB_DIF_H 47
-#define GRAB_DIF_Y 480
-#define GRAB_DIF_CHALLENGING_X 425
-#define GRAB_DIF_CHALLENGING_X_DIMMED 485
-#define GRAB_DIF_NORMAL_X 545
-#define GRAB_DIF_NORMAL_X_DIMMED 605
-#define GRAB_DIF_EASY_X 665
-#define GRAB_DIF_EASY_X_DIMMED 725
-
-/* Blitting locations */
-
 #define TILES_EASY 15
 #define TILES_NORMAL 18
 #define TILES_CHALLENGING 21
 #define TILES_MAX TILES_CHALLENGING
 
+
+/* Locations of graphic UI elements in the UI file */
+#define GRAB_CLOSE_BUTTON_X 730
+#define GRAB_CLOSE_BUTTON_Y 11
+#define GRAB_CLOSE_BUTTON_X_DOWN 0
+#define GRAB_CLOSE_BUTTON_Y_DOWN 480
+
+#define GRAB_SHUFFLE_BUTTON_X 730
+#define GRAB_SHUFFLE_BUTTON_Y 82
+#define GRAB_SHUFFLE_BUTTON_X_DOWN 60
+#define GRAB_SHUFFLE_BUTTON_Y_DOWN 480
+
+#define GRAB_UP_X 269
+#define GRAB_UP_Y 530
+#define GRAB_UP_X_DOWN 405
+#define GRAB_UP_Y_DOWN 530
+#define GRAB_UP_X_DIMMED 541
+#define GRAB_UP_Y_DIMMED 530
+
+#define GRAB_DOWN_X 337
+#define GRAB_DOWN_Y 530
+#define GRAB_DOWN_X_DOWN 473
+#define GRAB_DOWN_Y_DOWN 530
+#define GRAB_DOWN_X_DIMMED 609
+#define GRAB_DOWN_Y_DIMMED 530
+
+#define GRAB_NUMBERS_X 266
+#define GRAB_NUMBERS_Y 485
+#define GRAB_TILEBACK_X 161
+#define GRAB_TILEBACK_Y 480
+
+#define GRAB_DIF_W 61
+#define GRAB_DIF_H 46
+#define GRAB_DIF_Y 480
+#define GRAB_DIF_CHALLENGING_X 422
+#define GRAB_DIF_CHALLENGING_X_DIMMED 483
+#define GRAB_DIF_NORMAL_X 544
+#define GRAB_DIF_NORMAL_X_DIMMED 605
+#define GRAB_DIF_EASY_X 666
+#define GRAB_DIF_EASY_X_DIMMED 727
+
+/* Blitting locations */
+
 #define TILE_GFX_HEIGHT 70
 #define TILE_GFX_WIDTH 100
 
@@ -93,24 +92,24 @@
 #define COUNTER_Y_START 430
 #define COUNTER_TEXT_HEIGHT 27
 #define COUNTER_TEXT_WIDTH 15
-#define UPDOWN_BUTTON_X 745
-#define UPDOWN_BUTTON_W 27
-#define UPDOWN_BUTTON_H 12
+#define UPDOWN_BUTTON_X 730
+#define UPDOWN_BUTTON_W 60
+#define UPDOWN_BUTTON_H 25
 #define UP_BUTTON_Y 320
-#define DOWN_BUTTON_Y 382
+#define DOWN_BUTTON_Y 384
 
 #define THUMBNAIL_X 735
-#define THUMBNAIL_Y 341
-#define DIFFICULTY_X 731
-#define DIFFICULTY_CHALLENGING_Y 173
-#define DIFFICULTY_NORMAL_Y 216
-#define DIFFICULTY_EASY_Y 259
+#define THUMBNAIL_Y 347
+#define DIFFICULTY_X 729
+#define DIFFICULTY_CHALLENGING_Y 168
+#define DIFFICULTY_NORMAL_Y 214
+#define DIFFICULTY_EASY_Y 260
 
-#define BIGBUTTON_X 720
-#define BIGBUTTON_W 80
-#define BIGBUTTON_H 80
-#define CLOSE_BUTTON_Y 0
-#define SHUFFLE_BUTTON_Y 80
+#define BIGBUTTON_X 729
+#define BIGBUTTON_W 60
+#define BIGBUTTON_H 70
+#define CLOSE_BUTTON_Y 11
+#define SHUFFLE_BUTTON_Y 82
 
 #define THUMB_MID 400
 #define THUMB_SHIFT 25
@@ -168,7 +167,6 @@ static SDL_Surface *ui;
 static PressedButton bp;
 static int bootthumbnails;
 
-sapp_data *main_ctx = NULL;
 int exit_state = 0;
 GList *tilesets;
 GList *current_tileset;
@@ -320,7 +318,7 @@ BlitDifficulty(int tilecount)
 	bsrc.x = 720;
 	bsrc.y = 160;
 	bsrc.w = 80;
-	bsrc.h = 140;
+	bsrc.h = 160;
 	SDL_BlitSurface (ui, &bsrc, screen, &bsrc);
 	SDL_UpdateRect (screen, bsrc.x, bsrc.y, bsrc.w, bsrc.h);
 
@@ -417,13 +415,38 @@ InitAndDraw (PressedButton b)
 {
 	int i, j;
 	
-	if ((b == BNone) || (b == BChallenging) || (b == BNormal) || (b == BEasy)) 
+	if (b == BNone) 
 	{
+		/* No button, full blit of UI */
 		src.w = 800; 
 		src.h = 480;
 		src.y = src.x = 0;
 		SDL_BlitSurface (ui, &src, screen, &src);
 		SDL_UpdateRect (screen, 0, 0, 0, 0);
+	} else {
+		/* Button, blit only playfield surroundings, rest will be covered by tiles anyway */
+		src.x = 0;
+		src.w = left_margin;
+		src.y = 0;
+		src.h = 480;
+		SDL_BlitSurface (ui, &src, screen, &src);
+		SDL_UpdateRect (screen, src.x, src.y, src.w, src.h);
+		src.x = 720 - left_margin;
+		src.w = left_margin;
+		src.y = 0;
+		src.h = 480;
+		SDL_BlitSurface (ui, &src, screen, &src);
+		SDL_UpdateRect (screen, src.x, src.y, src.w, src.h);
+		src.x = left_margin;
+		src.w = 720 - 2*left_margin;
+		src.y = 0;
+		src.h = top_margin;
+		SDL_BlitSurface (ui, &src, screen, &src);
+		SDL_UpdateRect (screen, src.x, src.y, src.w, src.h);
+		src.y = 480 - top_margin;
+		src.h = top_margin;
+		SDL_BlitSurface (ui, &src, screen, &src);
+		SDL_UpdateRect (screen, src.x, src.y, src.w, src.h);
 	}
 
 	/* Generate game map */
@@ -789,10 +812,49 @@ BlitButton (PressedButton b, ButtonStates s)
 			SDL_UpdateRect (screen, ld.x, ld.y, ld.w, ld.h);		
 			break;
 		case BEasy:	
+			ld.x = DIFFICULTY_X;
+			ld.y = DIFFICULTY_EASY_Y;
+			ld.w = ls.w = GRAB_DIF_W;
+			ld.h = ls.h = GRAB_DIF_H;
+			if (s == SDown) {
+				ls.x = GRAB_DIF_EASY_X_DIMMED;
+				ls.y = GRAB_DIF_Y;
+			} else {
+				ls.x = GRAB_DIF_EASY_X;
+				ls.y = GRAB_DIF_Y;
+			}
+			SDL_BlitSurface (ui, &ls, screen, &ld);
+			SDL_UpdateRect (screen, ld.x, ld.y, ld.w, ld.h);		
 			break;
 		case BNormal:
+			ld.x = DIFFICULTY_X;
+			ld.y = DIFFICULTY_NORMAL_Y;
+			ld.w = ls.w = GRAB_DIF_W;
+			ld.h = ls.h = GRAB_DIF_H;
+			if (s == SDown) {
+				ls.x = GRAB_DIF_NORMAL_X_DIMMED;
+				ls.y = GRAB_DIF_Y;
+			} else {
+				ls.x = GRAB_DIF_NORMAL_X;
+				ls.y = GRAB_DIF_Y;
+			}
+			SDL_BlitSurface (ui, &ls, screen, &ld);
+			SDL_UpdateRect (screen, ld.x, ld.y, ld.w, ld.h);
 			break;
 		case BChallenging:
+			ld.x = DIFFICULTY_X;
+			ld.y = DIFFICULTY_CHALLENGING_Y;
+			ld.w = ls.w = GRAB_DIF_W;
+			ld.h = ls.h = GRAB_DIF_H;
+			if (s == SDown) {
+				ls.x = GRAB_DIF_CHALLENGING_X_DIMMED;
+				ls.y = GRAB_DIF_Y;
+			} else {
+				ls.x = GRAB_DIF_CHALLENGING_X;
+				ls.y = GRAB_DIF_Y;
+			}
+			SDL_BlitSurface (ui, &ls, screen, &ld);
+			SDL_UpdateRect (screen, ld.x, ld.y, ld.w, ld.h);
 			break;
 		case BUp:
 			ld.x = UPDOWN_BUTTON_X;
@@ -1066,8 +1128,6 @@ start:
 int
 main (int argc, char *argv[])
 {
-	SDL_bool have_tunjo = SDL_TRUE;
-	
 	putenv("SDL_VIDEO_X11_WMCLASS=nako");
 	
 	if (SDL_Init (SDL_INIT_VIDEO) != 0)
@@ -1076,29 +1136,6 @@ main (int argc, char *argv[])
 		return (1);
 	}
 
-	main_ctx = sapp_initialize(argc, argv);
-	if(!main_ctx)
-	{
-		fprintf(stderr, "Cannot init tunjo\n");
-		have_tunjo = SDL_FALSE;
-	}
-
-	if (have_tunjo)
-	{
-		sapp_set_msg_cb_flush(main_ctx, kill_the_state_file);
-		sapp_set_msg_cb_restart(main_ctx, restartgame);
-		sapp_set_msg_cb_continue(main_ctx, stoppause);
-		sapp_set_msg_cb_exit(main_ctx, deinitandsave);
-		sapp_set_msg_cb_quit(main_ctx, quitgamedontsave);
-		sapp_set_msg_cb_top(main_ctx, topthewindow);
-	
-		if(!sapp_check(main_ctx))
-		{
-			SDL_Quit();
-			return 0;
-		}
-	}
-
 	atexit (SDL_Quit);
 	screen = SDL_SetVideoMode (800, 480, 16, SDL_FULLSCREEN);
 	if (screen == NULL)
@@ -1111,52 +1148,5 @@ main (int argc, char *argv[])
 	InitGame ();
 	GameLoop ();
 
-	if (have_tunjo)
-	{
-		if(exit_state)
-		{
-			sapp_quit(main_ctx);
-		}
-		else
-		{
-			sapp_deinitialize(main_ctx);
-		}
-	}
-	return 0;
-}
-
-int kill_the_state_file(int bohoo)
-{
-fprintf(stderr, "Got kill_the_state_file\n");
-	return 0;
-}
-
-int restartgame(int bohoo)
-{
-fprintf(stderr, "Got restartgame\n");
-	return 0;
-}
-
-int stoppause(int bohoo)
-{
-fprintf(stderr, "Got stoppause\n");
-	return 0;
-}
-
-int deinitandsave(int bohoo)
-{
-fprintf(stderr, "Got deinitandsave\n");
-	return 0;
-}
-
-int quitgamedontsave(int bohoo)
-{
-fprintf(stderr, "Got quitgamedontsave\n");
-	return 0;
-}
-
-int topthewindow(int bohoo)
-{
-fprintf(stderr, "Got topthewindow\n");
 	return 0;
 }
